@@ -1,8 +1,8 @@
 extern crate subparse;
 
-use subparse::timetypes::TimeDelta;
-use subparse::SubtitleEntry;
 use subparse::{get_subtitle_format, parse_str};
+use subparse::SubtitleEntry;
+use subparse::timetypes::TimeDelta;
 
 /// This function reads the content of a file to a `String`.
 fn read_file(path: &str) -> String {
@@ -21,7 +21,9 @@ fn main() {
     // parse the file
     let format = get_subtitle_format(path, file_content.as_bytes()).expect("unknown format");
     let mut subtitle_file = parse_str(format, &file_content, 25.0).expect("parser error");
-    let mut subtitle_entries: Vec<SubtitleEntry> = subtitle_file.get_subtitle_entries().expect("unexpected error");
+    let mut subtitle_entries: Vec<SubtitleEntry> = subtitle_file.get_subtitle_entries().expect(
+        "unexpected error",
+    );
 
     // shift all subtitle entries by 1 minute and append "subparse" to each subtitle line
     for subtitle_entry in &mut subtitle_entries {
@@ -35,7 +37,8 @@ fn main() {
     }
 
     // update the entries in the subtitle file
-    subtitle_file.update_subtitle_entries(&subtitle_entries).expect("unexpected error");
+    subtitle_file.update_subtitle_entries(&subtitle_entries)
+                 .expect("unexpected error");
 
     // print the corrected file to stdout
     let data: Vec<u8> = subtitle_file.to_data().expect("unexpected errror");
