@@ -4,12 +4,12 @@
 
 
 use SubtitleFormat;
+pub use formats::idx::errors as idx_errors;
+pub use formats::microdvd::errors as mdvd_errors;
 
 pub use formats::srt::errors as srt_errors;
 pub use formats::ssa::errors as ssa_errors;
-pub use formats::idx::errors as idx_errors;
 pub use formats::vobsub::errors as vob_errors;
-pub use formats::microdvd::errors as mdvd_errors;
 
 // see https://docs.rs/error-chain/0.8.1/error_chain/
 #[cfg_attr(rustfmt, rustfmt_skip)]
@@ -49,6 +49,11 @@ error_chain! {
             description("unknown file format, only SubRip (.srt), SubStationAlpha (.ssa/.ass) and VobSub (.idx and .sub) are supported at the moment")
         }
 
+        /// The file format is not supported by this library.
+        DecodingError {
+            description("error while decoding subtitle from bytes to string (wrong charset encoding?)")
+        }
+
         /// The attempted operation does not work on binary subtitle formats.
         TextFormatOnly {
             description("operation does not work on binary subtitle formats (only text formats)")
